@@ -1,15 +1,15 @@
-/*
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- *
  * gtksourcecompletionmodel.c
- * This file is part of gtksourcecompletion
+ * This file is part of GtkSourceView
  *
  * Copyright (C) 2009 - Jesse van den Kieboom <jessevdk@gnome.org>
  *
- * gtksourceview is free software; you can redistribute it and/or
+ * GtkSourceView is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
  *
- * gtksourceview is distributed in the hope that it will be useful,
+ * GtkSourceView is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
@@ -33,9 +33,9 @@ typedef struct
 	GtkSourceCompletionProposal *proposal;
 
 	gulong changed_id;
-	gboolean mark;
-	
-	gboolean filtered;
+
+	guint mark : 1;
+	guint filtered : 1;
 } ProposalNode;
 
 typedef struct
@@ -43,12 +43,12 @@ typedef struct
 	GtkSourceCompletionProvider *provider;
 	GHashTable *proposals;
 	guint num_proposals;
-	gboolean filtered;
 
 	GList *first;
 	GList *last;
 	GList *ptr;
-	gboolean first_batch;
+	guint first_batch : 1;
+	guint filtered : 1;
 } ProviderInfo;
 
 struct _GtkSourceCompletionModelPrivate
@@ -62,9 +62,9 @@ struct _GtkSourceCompletionModelPrivate
 	GList *visible_providers;
 	
 	guint num;
-	gboolean show_headers;
-	
-	gboolean marking;
+
+	guint show_headers : 1;
+	guint marking : 1;
 };
 
 enum
@@ -1355,7 +1355,9 @@ gtk_source_completion_model_set_show_headers (GtkSourceCompletionModel *model,
                                               gboolean                  show_headers)
 {
 	g_return_if_fail (GTK_IS_SOURCE_COMPLETION_MODEL (model));
-	
+
+	show_headers = (show_headers != FALSE);
+
 	if (model->priv->show_headers != show_headers)
 	{
 		model->priv->show_headers = show_headers;
